( cd usr/doc/yaboot-1.3.13/doc/yaboot-howto.html ; rm -rf index.html )
( cd usr/doc/yaboot-1.3.13/doc/yaboot-howto.html ; ln -sf index.en.html index.html )
( cd usr/sbin ; rm -rf mkofboot )
( cd usr/sbin ; ln -sf ybin mkofboot )
